@@ -1,4 +1,4 @@
-package Pcore::Chrome v0.1.0;
+package Pcore::Chrome v0.1.1;
 
 use Pcore -dist, -const, -class;
 use Pcore::Chrome::Tab;
@@ -9,13 +9,21 @@ use Pcore::WebSocket;
 has host => ( is => 'ro', isa => Str, default => '127.0.0.1' );
 has port => ( is => 'ro', isa => Int, default => 9222 );
 
-has _proc => ( is => 'ro', isa => InstanceOf ['Pcore::Util:PM::Proc'], init_arg => undef );
 has user_data_dir => ( is => 'ro', init_arg => undef );
+has _proc => ( is => 'ro', isa => InstanceOf ['Pcore::Util:PM::Proc'], init_arg => undef );
 
 const our $DEFAULT_USERAGENT => 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/60.0.3112.101 Safari/537.36';
 
 # https://chromedevtools.github.io/devtools-protocol/tot/
 
+sub DEMOLISH ( $self, $global ) {
+
+    # term process group
+    kill '-TERM', $self->{_proc}->{pid} if $self->{_proc};    ## no critic qw[InputOutput::RequireCheckedSyscalls]
+
+    return;
+}
+
 sub run ( $self, @args ) {
     my $blocking_cv = defined wantarray ? AE::cv : undef;
 
@@ -23,7 +31,7 @@ sub run ( $self, @args ) {
 
     my %args = @args;
 
-    $args{bin} ||= $MSWIN ? q["c:/Program Files (x86)/Google/Chrome/Application/chrome.exe"] : '/usr/bin/google-chrome';
+    $args{bin} ||= $MSWIN ? "$ENV{'ProgramFiles(x86)'}/Google/Chrome/Application/chrome.exe" : '/usr/bin/google-chrome';
 
     $args{host} ||= '127.0.0.1';
 
@@ -34,7 +42,7 @@ sub run ( $self, @args ) {
     $self->{user_data_dir} = P->file->tempdir;
 
     my $cmd = [
-        $args{bin},
+        qq["$args{bin}"],
 
         "--remote-debugging-address=$args{host}",
         "--remote-debugging-port=$args{port}",
@@ -42,32 +50,50 @@ sub run ( $self, @args ) {
         '--disable-background-networking',
         '--disable-client-side-phishing-detection',
         '--disable-component-update',
-        '--disable-default-apps',
         '--disable-hang-monitor',
         '--disable-prompt-on-repost',
         '--disable-sync',
         '--disable-web-resources',
 
-        # '--window-size=800x600',
         '--start-maximized',
+        '--window-size=1280x720',
+
         '--disable-default-apps',
         '--no-first-run',
         '--disable-infobars',
         '--disable-popup-blocking',
         '--disable-default-apps',
         '--disable-web-security',
+        '--allow-running-insecure-content',
 
-        "--user-data-dir=$self->{user_data_dir}",
-        '--no-sandbox',    # required for run under docker
+        # logging
+        # '--disable-logging',
+        # '--log-level=0',
 
-        # TODO defined $useragent ? qq[--user-agent="$useragent"] : (),
+        # set user profile dir
+        qq[--user-data-dir="$self->{user_data_dir}"],
 
+        # required for run under docker
+        '--no-sandbox',
+
+        # user agent
+        defined $useragent ? qq[--user-agent="$useragent"] : (),
+
+        # headless mode
         $args{headless} || !$MSWIN ? ( '--headless', '--disable-gpu' ) : (),
+
+        # user args
         $args{args} ? $args{args}->@* : (),
+
+        # open "about:blank" by default
+        'about:blank',
+
+        # redirect STDERR under linux
+        !$MSWIN ? '2>/dev/null' : (),
     ];
 
     P->pm->run_proc(
-        $cmd,
+        join( q[ ], $cmd->@* ),
         win32_create_no_window => 1,
         on_ready               => sub ($proc) {
             $self->{_proc} = $proc;
@@ -108,7 +134,7 @@ sub get_tabs ( $self, $cb ) {
 sub new_tab ( $self, @args ) {
     my $cb = is_plain_coderef $args[-1] ? pop @args : undef;
 
-    my $url = $args[0] ? "?$args[0]" : q[];
+    my $url = $args[0] ? "?$args[0]" : q[?about:blank];
 
     P->http->get(
         "http://$self->{host}:$self->{port}/json/new$url",
@@ -133,7 +159,7 @@ sub new_tab ( $self, @args ) {
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ## | Sev. | Lines                | Policy                                                                                                         |
 ## |======+======================+================================================================================================================|
-## |    2 | 65                   | CodeLayout::ProhibitQuotedWordLists - List of quoted literal words                                             |
+## |    2 | 83                   | CodeLayout::ProhibitQuotedWordLists - List of quoted literal words                                             |
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ##
 ## -----SOURCE FILTER LOG END-----
@@ -148,6 +174,16 @@ Pcore::Chrome
 
 =head1 SYNOPSIS
 
+    use Pcore::Chrome;
+
+    my $chrome = Pcore::Chrome->new->run(
+        host      => '127.0.0.1',
+        port      => 9222,
+        bin       => undef,
+        headless  => 1,
+        useragent => undef,
+    );
+
 =head1 DESCRIPTION
 
 =head1 ATTRIBUTES
