@@ -13,13 +13,19 @@ use overload    #
 has chrome => ( is => 'ro', isa => InstanceOf ['Pcore::WebDriver::ChromeDevTools'], required => 1 );
 has id => ( is => 'ro', isa => Str, required => 1 );
 
-has _ws => ( is => 'ro', isa => InstanceOf ['Pcore::WebSocket::Protocol::raw'], init_arg => undef );
 has listen => ( is => 'ro', isa => HashRef );
 
+has _ws => ( is => 'ro', isa => InstanceOf ['Pcore::WebSocket::Protocol::raw'], init_arg => undef );
 has _cb => ( is => 'ro', isa => HashRef, init_arg => undef );
 
 our $_MSG_ID = 0;
 
+sub new_tab ( $self, @args ) {
+    $self->{chrome}->new_tab(@args);
+
+    return;
+}
+
 sub close ( $self, $cb = undef ) {    ## no critic qw[Subroutines::ProhibitBuiltinHomonyms NamingConventions::ProhibitAmbiguousNames]
     P->http->get(
         "http://$self->{chrome}->{host}:$self->{chrome}->{port}/json/close/$self->{id}",
